@@ -555,6 +555,7 @@ class ParamEditor(QtWidgets.QDockWidget):
       def populateFunc():
         self.addDirItemsToMenu(newMenuOrAct)
       self.sigParamStateCreated.connect(populateFunc)
+      self.sigParamStateDeleted.connect(populateFunc)
       # Initialize default menus
       populateFunc()
       if parentMenu is not None:
@@ -586,7 +587,7 @@ class ParamEditor(QtWidgets.QDockWidget):
     dirStates = [f.stem for f in dirGlob]
 
     newStates = set(dirStates) - set(self.savedStates)
-    delStates = set(self.savedStates) - set(newStates)
+    delStates = set(self.savedStates) - set(dirStates)
 
     self.savedStates = dirStates
     # Kind of a hack: Make sure no sigValueChange is emmittedto until after setLimits
