@@ -1,5 +1,6 @@
 from __future__ import annotations
 
+import weakref
 from typing import Optional, Callable, Sequence
 
 from pyqtgraph.Qt import QtWidgets
@@ -145,7 +146,21 @@ class ParamEditorPlugin(pe.EditorPropsMixin):
     self.menu.setParent(self.parentMenu, self.menu.windowFlags())
     for proc in self.toolsEditor.procToParamsMapping:
       proc.updateInput(win=win)
+    if self.dock:
+      self.dock.win = weakref.proxy(win)
 
+  def addToWindow(self, win: QtWidgets.QMainWindow, parentToolbarOrMenu=None):
+    if parentToolbarOrMenu is None:
+      parentToolbarOrMenu = win.menuBar()
+    if isinstance(parentToolbarOrMenu, QtWidgets.QToolBar):
+      btn = QtWidgets.QToolButton()
+      btn.setText(self.name)
+      parentToolbarOrMenu.addWidget(btn)
+      parentToolbarOrMenu = btn
+      btn.addMenu = btn.setMenu
+      btn.addAction = lambda act: act.triggered.connect(btn.click)
+      btn.setPopupMode(btn.InstantPopup)
+    parentToolbarOrMenu.addMenu(self.menu)
 
 def dockPluginFactory(name_: str=None, editors: Sequence[pe.ParamEditor]=None):
   class DummyPlugin(ParamEditorPlugin):
