@@ -44,7 +44,7 @@ def _mkProcParam(stage: ProcessStage):
   return {'name': stage.name, 'type': 'procgroup', 'process': stage, 'enabled': not stage.disabled}
 
 def atomicRunWrapper(proc: AtomicProcess, param: Parameter):
-  param.sigValueChanged.connect(lambda p, val: proc.updateInput(graceful=True, **{param.name(): val}))
+  param.sigValueChanged.connect(lambda p, val: proc.input.update(**{param.name(): val}))
 
 @singledispatch
 def addStageToParam(stage: ProcessStage, parentParam: Parameter, **kwargs):
@@ -87,8 +87,7 @@ def addNestedToParam(stage: NestedProcess, parentParam: Parameter, nestHyperpara
   if nestHyperparams:
     parentParam = fns.getParamChild(parentParam, chOpts=_mkProcParam(stage))
   if treatAsAtomic:
-    collapsed = AtomicProcess(stage.run, stage.name, mainResultKeys=stage.mainResultKeys,
-                              mainInputKeys=stage.mainInputKeys)
+    collapsed = AtomicProcess(stage.run, stage.name)
     collapsed.input = stage.input
     addAtomicToParam(collapsed, parentParam, argNameFormat)
     return
